Django Jet
====

Modern template for Django admin interface with improved functionality
Free for non-commercial use. If you would like to use it in commercial project, please email at support@jet.geex-arts.com

Beta
====
Current version is still in beta phase. Use it at your own risk (though may be already enough for using in real projects).

Demo
====
Incoming

Documentation
====
Incoming

Support
====
support@jet.geex-arts.com

